pub trait Queryable {
type KeyValue: Debug + QueryKeyValue + Clone;
// Required method
fn matches(&self, key: &Self::KeyValue) -> bool;
}Expand description
Specific trait that specifies that something can be matched by a
Query.
Required Associated Types
Sourcetype KeyValue: Debug + QueryKeyValue + Clone
type KeyValue: Debug + QueryKeyValue + Clone
The type defining the possible keys a user can input.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".